@@ -33,7 +33,7 @@ clim_spread <- function(data, clim_start, clim_end, windowHalfWidth) {
   rm(data)
 
   data.table::setDT(ts_clim)[, ts_x := format(as.Date(ts_x), "%Y") ]
-  ts_spread <- data.table::dcast(ts_clim, doy ~ ts_x, value.var = "ts_y")
+  ts_spread <- data.table::dcast(ts_clim, doy ~ ts_x, value.var = "ts_y", mean)
   rm(ts_clim)
 
   ts_spread_filled <- data.table::data.table((sapply(ts_spread[59:61, ],
