@@ -34,9 +34,9 @@
 #' @param start_date The start date of a period of time within which the largest
 #' event (as per \code{metric}) is retrieved and plotted. This may not necessarily
 #' correspond to the biggest event of the specified metric within the entire
-#' data set. To plot the biggest event within the whole time series, make sure
-#' \code{start_date} and \code{end_date} straddle this event, or simply specify
-#' the start and end dates of the full time series given to \code{\link{detect_event}}.
+#' time series. To plot the largest event within the whole time series, make sure
+#' \code{start_date} and \code{end_date} straddle this event, or simply leave them both
+#' as NULL (default) and \code{event_line} will use the entire time series date range.
 #' @param end_date The end date of a period of time within which the largest
 #' event (as per \code{metric}) is retrieved and plotted. See \code{start_date}
 #' for additional information.
@@ -79,19 +79,25 @@ event_line <- function(data,
                        min_duration = 5,
                        spread = 150,
                        metric = "intensity_cumulative",
-                       start_date,
-                       end_date,
+                       start_date = NULL,
+                       end_date = NULL,
                        category = FALSE) {
 
   date_end <- date_start <- duration <-  temp <-  NULL
 
-  if (!(exists("event", data)) | !(exists("climatology", data))) stop("Please ensure you are running this function on the output of 'heatwaveR::detect_event()'")
+  if (!(exists("event", data)) | !(exists("climatology", data)))
+    stop("Please ensure you are running this function on the output of 'heatwaveR::detect_event()'")
 
   ts.x <- eval(substitute(x), data$climatology)
   data$climatology$ts.x <- ts.x
   ts.y <- eval(substitute(y), data$climatology)
   data$climatology$ts.y <- ts.y
 
+  if (is.null(start_date))
+    start_date <- min(data$climatology$ts.x)
+  if (is.null(end_date))
+    end_date <- max(data$climatology$ts.x)
+
   event <- data$event %>%
     dplyr::filter(date_end >= start_date & date_start <= end_date)
 
@@ -115,6 +121,10 @@ event_line <- function(data,
 
   date_spread <- seq((event_top$date_start - spread), (event_top$date_end + spread), by = "day")
 
+  event_sub <- event %>%
+    dplyr::filter(date_start >= min(date_spread),
+           date_end <= max(date_spread))
+
   thresh_2x <- thresh_3x <- thresh_4x <- NULL
 
   clim_diff <- data$climatology %>%
@@ -124,8 +134,8 @@ event_line <- function(data,
            thresh_4x = thresh_3x + diff)
 
   clim_events <- data.frame()
-  for (i in 1:nrow(event)) {
-    clim_sub <- clim_diff[(event$index_start_fix[i]):(event$index_end_fix[i]),]
+  for (i in 1:nrow(event_sub)) {
+    clim_sub <- clim_diff[(event_sub$index_start_fix[i]):(event_sub$index_end_fix[i]),]
     clim_events <- rbind(clim_events, clim_sub)
   }
 
@@ -150,7 +160,7 @@ event_line <- function(data,
     clim_top$y2 <- clim_top$ts.y
   }
 
-  ylabel <- expression(paste("Temperautre [", degree, "C]"))
+  ylabel <- expression(paste("Temperature [", degree, "C]"))
 
   ep <- ggplot(data = clim_spread, aes(x = ts.x, y = ts.y)) +
     scale_x_date(expand = c(0, 0), date_labels = "%b %Y", name = NULL) +
